aboutsummaryrefslogtreecommitdiffhomepage
path: root/public/bluebey-studio/src/presets.js
diff options
context:
space:
mode:
Diffstat (limited to 'public/bluebey-studio/src/presets.js')
-rw-r--r--public/bluebey-studio/src/presets.js4
1 files changed, 3 insertions, 1 deletions
diff --git a/public/bluebey-studio/src/presets.js b/public/bluebey-studio/src/presets.js
index 4ae17b3..0862fcd 100644
--- a/public/bluebey-studio/src/presets.js
+++ b/public/bluebey-studio/src/presets.js
@@ -204,8 +204,10 @@ export function defaultState() {
lidWidth: 14,
lowerLid: 0,
// How the closing eyelid is drawn: `curve` is the soft, rounded lid; `flat`
// is a straight lid edge (the hard, narrowed look). See faceArt.js.
lidShape: 'curve',
+ lidTilt: 0,
heartScale: 2,
heartColor: '#e0344f',
heartHideWhite: true,
@@ -204,8 +204,10 @@ export function defaultState() {
lowerLid: 0,
// How the closing eyelid is drawn: `curve` is the soft, rounded lid; `flat`
- // is a straight lid edge (the hard, narrowed look). See faceArt.js.
+ // is a straight lid edge (the hard, narrowed look). `lidTilt` rotates the
+ // narrowed eye. See faceArt.js.
lidShape: 'curve',